// ProgressDlg.cpp : implementation file
//

#include "stdafx.h"
#include "rootfly.h"
#include "ProgressDlg.h"
#include "TubeControl.h"
#include "DataStructures.h"

#include <sstream>
#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// ProgressDlg dialog


ProgressDlg::ProgressDlg(ProgressData *data, const CString &tube, const std::vector<Date> session_dates, CWnd* pParent /*=NULL*/)
: CDialog(ProgressDlg::IDD, pParent), m_tube_view(data)
{
	//{{AFX_DATA_INIT(ProgressDlg)
	//}}AFX_DATA_INIT

  m_progress_data = data;
  m_selected_tube = m_selected_session = m_selected_window = -1;
  m_select_image.m_dlg = this;
  m_tube_view.SetImageSelectCallback(&m_select_image);
  m_initial_tube = tube;
}


void ProgressDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(ProgressDlg)
	DDX_Control(pDX, IDC_TUBE_VIEW, m_tube_view);
	DDX_Control(pDX, IDC_TOTAL_ANNOTATED, m_total_annotated);
	DDX_Control(pDX, IDC_TOTAL_IMAGES, m_total_images);
	DDX_Control(pDX, IDC_PROGRESS_SESSION, m_tube_selection);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(ProgressDlg, CDialog)
	//{{AFX_MSG_MAP(ProgressDlg)
	ON_CBN_SELCHANGE(IDC_PROGRESS_SESSION, OnSelchangeProgress)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// ProgressDlg message handlers

BOOL ProgressDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();
	
	// TODO: Add extra initialization here

  InitTotals();
  InitSelection();

  m_tube_view.SetTube(m_initial_tube);
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

void ProgressDlg::InitTotals()
{
  CString text;

  text.Format("Total Images: %d", m_progress_data->GetImageCount());
  m_total_images.SetWindowText(text);
  
  text.Format("Total Annotated: %d", m_progress_data->GetAnnotatedCount());
  m_total_annotated.SetWindowText(text);
}

void ProgressDlg::InitSelection()
{
  int count = 0;
  CString item;
  CString tag;
  std::vector<bool> tubeList = *m_progress_data->GetTubeList();

  for(int i = 0; i < tubeList.size(); i++)
  {
	if(tubeList[i])
	{
		item.Format("Tube %d", i);
		m_tube_selection.AddString(item);

		if (i == stringToInt(m_initial_tube))//m_selected_tube?
		{
			m_tube_selection.SetCurSel(count);
		}
		count++;
	}
  }
}

void ProgressDlg::OnSelchangeProgress() 
{
	CString text;
	m_tube_selection.GetLBText(m_tube_selection.GetCurSel(),text);
	int tube = stripString(text);
	m_tube_view.SetTube(tube);

  m_tube_view.RedrawWindow();
}


int ProgressDlg::stripString(CString strip_string)
{
	CString temp;
	for(int i=strip_string.ReverseFind(' ');i<strip_string.GetLength();i++){
		temp+=strip_string.GetAt(i);
	}
	int n;
	std::string toIntString(temp);
	std::stringstream ss(toIntString);
    ss >> n;

	//if(n==4)
		//MessageBox("corrent int","strip string");
    return n;
}

int ProgressDlg::stringToInt(const CString &str)
{
	std::string temp(str);
	std::stringstream ss(temp);
    int n;
    ss >> n;
	return n;
}

void ProgressDlg::SelectImage(const int &tube, const int &session, const int &window)
{
  m_selected_tube = tube;
  m_selected_session = session;
  m_selected_window = window;

  OnOK();
}

// this set up may seem overly complicated, but it does avoid required TubeControl to have knowledge of ProgressDlg
void ProgressDlg::ImageSelectCallback::SelectImage(const int &tube, const int &session, const int &window)
{
  m_dlg->SelectImage(tube, session, window);
}
